# coding: utf8

from email.header import Header
from email.mime.text import MIMEText
from email.mime.multipart import MIMEBase, MIMEMultipart
from email.utils import parseaddr, formataddr
import smtplib


class SendEmail:
    def __init__(self, sender, receiver, smtp, password, port=25, filepath=None, filename=None, subject=None,
                 content=None,
                 _subtype='plain'):
        self.sender = sender
        self.receiver = receiver
        self.smtp = smtp
        self.port = port
        self._subtype = _subtype
        self.password = password
        self.filepath = filepath
        self.filename = filename
        self.subject = subject
        self.content = content

    def send_email(self):
        def _format_addr(s):
            name, addr = parseaddr(s)
            return formataddr(( \
                Header(name, 'utf-8').encode(), \
                addr.encode('utf-8') if isinstance(addr, unicode) else addr))

        msg = MIMEMultipart()
        msg['From'] = _format_addr(u'<%s>' % self.sender)
        msg['To'] = _format_addr(u'<%s>' % self.receiver)
        if self.subject:
            msg['Subject'] = Header(u'%s' % self.subject, 'utf-8').encode()

        msg.attach(MIMEText(self.content, _subtype=self._subtype, _charset='utf-8'))
        if self.filepath:
            att = MIMEText(open(self.filepath, 'rb').read(), 'base64', 'utf-8')
            att["Content-Type"] = 'application/octet-stream'
            att["Content-Disposition"] = 'attachment; filename=%s' % self.filename

            msg.attach(att)

        server = smtplib.SMTP(self.smtp, self.port)
        server.login(self.sender, self.password)
        server.sendmail(self.sender, [self.receiver], msg.as_string())
        server.quit()



import codecs
import os
import sys

try:
    from setuptools import setup
except:
    from distutils.core import setup

def read(fname):

    return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()

NAME = "easysendemail"

PACKAGES = ["easysendemail", ]

DESCRIPTION = "A simple package to send email."

LONG_DESCRIPTION = read("README.txt")

KEYWORDS = "email"

AUTHOR = "Klein"

AUTHOR_EMAIL = "juhongxiaoshou@163.com"


VERSION = "1.0.3"


setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    keywords=KEYWORDS,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    packages=PACKAGES,
    include_package_data=True,
    zip_safe=True,
)

